from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_ST_STM32WL = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'STM32WL54CCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WL54CCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WL5x', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wl54cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WL54CCUx\n\nArm Cortex-M4 STM32WL STM32WL5x', 'pins':[
            Pin(num='1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RFO_HP',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WL54JCIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WL54JCIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WL5x', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wl54jc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WL54JCIx\n\nArm Cortex-M4 STM32WL STM32WL5x', 'pins':[
            Pin(num='A1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='RFO_HP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WL55CCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WL55CCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WL5x', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wl55cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WL55CCUx\n\nArm Cortex-M4 STM32WL STM32WL5x', 'pins':[
            Pin(num='1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RFO_HP',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WL55JCIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WL55JCIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WL5x', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wl55jc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WL55JCIx\n\nArm Cortex-M4 STM32WL STM32WL5x', 'pins':[
            Pin(num='A1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='RFO_HP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE4C8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE4C8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle4c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE4C8Ux\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RFO_HP',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE4CBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE4CBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle4cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE4CBUx\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RFO_HP',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE4CCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE4CCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle4cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE4CCUx\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RFO_HP',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE4J8Ix', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE4J8Ix'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle4j8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE4J8Ix\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='A1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='RFO_HP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE4JBIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE4JBIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle4jb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE4JBIx\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='A1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='RFO_HP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE4JCIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE4JCIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle4jc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE4JCIx\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='A1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='RFO_HP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE5C8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE5C8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle5c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE5C8Ux\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RFO_HP',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE5CBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE5CBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle5cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE5CBUx\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RFO_HP',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE5CCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE5CCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle5cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE5CCUx\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RFO_HP',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE5J8Ix', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE5J8Ix'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle5j8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE5J8Ix\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='A1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='RFO_HP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE5JBIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE5JBIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle5jb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE5JBIx\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='A1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='RFO_HP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE5JCIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE5JCIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle5jc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE5JCIx\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='A1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='RFO_HP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Valve = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'CK6418', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CK6418'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Mini_Pentode_Linear'], 'footprint':'Valve:Valve_Mini_Pentode_Linear', 'keywords':'subminiature pentode valve', 'description':'', 'datasheet':'https://frank.pocnet.net/sheets/127/6/6418.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nCK6418\n\nsubminiature pentode valve', 'pins':[
            Pin(num='3',name='F+,G3',func=pin_types.PWRIN),
            Pin(num='1',name='P',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='G2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='F+,G3',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '5']}] }),
        Part(**{ 'name':'EABC80', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EABC80'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Noval_P'], 'footprint':'Valve:Valve_Noval_P', 'keywords':'diode triode valve', 'description':'', 'datasheet':'https://frank.pocnet.net/sheets/082/e/EABC80.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nEABC80\n\ndiode triode valve', 'pins':[
            Pin(num='2',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='K',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='A1',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='A3',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='K',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='K',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='G',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='A2',func=pin_types.OUTPUT,unit=3),
            Pin(num='4',name='F1',func=pin_types.INPUT,unit=4),
            Pin(num='5',name='F2',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '6', '1']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '9', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['5', '4']}] }),
        Part(**{ 'name':'EC92', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EC92'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Mini_P'], 'footprint':'Valve:Valve_Mini_P', 'keywords':'triode valve', 'description':'', 'datasheet':'http://www.r-type.org/pdfs/ec92.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nEC92\n\ntriode valve', 'pins':[
            Pin(num='1',name='A',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='K',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='F1',func=pin_types.PWRIN,unit=2),
            Pin(num='4',name='F2',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '7', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '3']}] }),
        Part(**{ 'name':'ECC81', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ECC81'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Noval_P'], 'footprint':'Valve:Valve_Noval_P', 'keywords':'triode valve', 'description':'', 'datasheet':'http://www.r-type.org/pdfs/ecc81.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nECC81\n\ntriode valve', 'pins':[
            Pin(num='6',name='A',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='K',func=pin_types.BIDIR,unit=1),
            Pin(num='1',name='A',func=pin_types.OUTPUT,unit=2),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='K',func=pin_types.BIDIR,unit=2),
            Pin(num='4',name='F1',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='F1',func=pin_types.PWRIN,unit=3),
            Pin(num='9',name='F2',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['8', '6', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '2', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '4', '9']}] }),
        Part(**{ 'name':'ECC88', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ECC88'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Noval_P'], 'footprint':'Valve:Valve_Noval_P', 'keywords':'triode valve', 'description':'', 'datasheet':'http://www.r-type.org/pdfs/ecc88.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nECC88\n\ntriode valve', 'pins':[
            Pin(num='1',name='A',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='K',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='A',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='G',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='K',func=pin_types.BIDIR,unit=2),
            Pin(num='4',name='F1',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='F2',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '7', '8']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '5']}] }),
        Part(**{ 'name':'ECH81', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ECH81'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Noval_P'], 'footprint':'Valve:Valve_Noval_P', 'keywords':'triode heptode valve', 'description':'', 'datasheet':'http://www.r-type.org/pdfs/ech81.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nECH81\n\ntriode heptode valve', 'pins':[
            Pin(num='3',name='K',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='A',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='G2_G4',func=pin_types.INPUT,unit=2),
            Pin(num='2',name='G1',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='A',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='G3',func=pin_types.INPUT,unit=2),
            Pin(num='~',name='K_G5',func=pin_types.BIDIR,unit=2),
            Pin(num='4',name='F1',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='F2',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['8', '3', '9']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '2', '~', '1', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '5']}] }),
        Part(**{ 'name':'ECL82', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ECL82'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Noval_P'], 'footprint':'Valve:Valve_Noval_P', 'keywords':'triode pentode valve', 'description':'', 'datasheet':'http://www.r-type.org/pdfs/ecl82.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nECL82\n\ntriode pentode valve', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='K',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='K_G3',func=pin_types.BIDIR,unit=2),
            Pin(num='3',name='G1',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='A',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='G2',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='F1',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='F2',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['9', '1', '8']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '3', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '4']}] }),
        Part(**{ 'name':'ECL86', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ECL86'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Noval_P'], 'footprint':'Valve:Valve_Noval_P', 'keywords':'triode pentode valve', 'description':'', 'datasheet':'http://www.r-type.org/pdfs/ecl86.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nECL86\n\ntriode pentode valve', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='K',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='G2',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='A',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='K_G3',func=pin_types.BIDIR,unit=2),
            Pin(num='8',name='G1',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='F1',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='F2',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '9']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '7', '8', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '4']}] }),
        Part(**{ 'name':'EF80', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EF80'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Noval_P'], 'footprint':'Valve:Valve_Noval_P', 'keywords':'pentode valve', 'description':'', 'datasheet':'http://www.r-type.org/pdfs/ef80.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nEF80\n\npentode valve', 'pins':[
            Pin(num='2',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='F1',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='G2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='G3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='F1',func=pin_types.PWRIN,unit=2),
            Pin(num='5',name='F2',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '8', '6', '2', '7', '9']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5']}] }),
        Part(**{ 'name':'EF83', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EF83'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Noval_P'], 'footprint':'Valve:Valve_Noval_P', 'keywords':'pentode valve', 'description':'', 'datasheet':'http://www.r-type.org/pdfs/ef83.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nEF83\n\npentode valve', 'pins':[
            Pin(num='1',name='G2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='K',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='A',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='G3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='F1',func=pin_types.PWRIN,unit=2),
            Pin(num='5',name='F2',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '8', '6', '7', '9', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5']}] }),
        Part(**{ 'name':'EL34', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EL34'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Octal'], 'footprint':'Valve:Valve_Octal', 'keywords':'pentode valve', 'description':'', 'datasheet':'http://www.r-type.org/pdfs/el34.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nEL34\n\npentode valve', 'pins':[
            Pin(num='1',name='G3',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='G2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='F1',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='F1',func=pin_types.PWRIN,unit=2),
            Pin(num='7',name='F2',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '5', '1', '8', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '2']}] }),
        Part(**{ 'name':'EL84', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EL84'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Noval_P'], 'footprint':'Valve:Valve_Noval_P', 'keywords':'pentode valve', 'description':'', 'datasheet':'http://www.r-type.org/pdfs/el84.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nEL84\n\npentode valve', 'pins':[
            Pin(num='2',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='K_G3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='A',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='G2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='F1',func=pin_types.PWRIN,unit=2),
            Pin(num='5',name='F2',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '2', '9', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5']}] }),
        Part(**{ 'name':'EM84', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EM84'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Noval_P'], 'footprint':'Valve:Valve_Noval_P', 'keywords':'indicator tube valve magic eye', 'description':'', 'datasheet':'http://www.r-type.org/pdfs/em84.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nEM84\n\nindicator tube valve magic eye', 'pins':[
            Pin(num='2',name='K',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='L',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='ST',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='G',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='A',func=pin_types.OUTPUT,unit=2),
            Pin(num='~',name='F1',func=pin_types.PWRIN,unit=2),
            Pin(num='4',name='F1',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='F2',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '7', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '9', '~']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '4']}] }),
        Part(**{ 'name':'STABI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STABI'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Glimm'], 'footprint':'Valve:Valve_Glimm', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nSTABI\n\n', 'pins':[
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'6AK8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'6AK8'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Noval_P', 'Valve:Valve_Noval_P'], 'footprint':'Valve:Valve_Noval_P', 'keywords':'diode triode valve', 'description':'', 'datasheet':'https://frank.pocnet.net/sheets/082/e/EABC80.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\n6AK8\n\ndiode triode valve', 'pins':[
            Pin(num='2',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='K',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='A1',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='A3',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='K',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='K',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='G',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='A2',func=pin_types.OUTPUT,unit=3),
            Pin(num='4',name='F1',func=pin_types.INPUT,unit=4),
            Pin(num='5',name='F2',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '7', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '9', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['5', '4']}] }),
        Part(**{ 'name':'9AK8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'9AK8'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Noval_P', 'Valve:Valve_Noval_P', 'Valve:Valve_Noval_P'], 'footprint':'Valve:Valve_Noval_P', 'keywords':'diode triode valve', 'description':'', 'datasheet':'https://frank.pocnet.net/sheets/082/e/EABC80.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\n9AK8\n\ndiode triode valve', 'pins':[
            Pin(num='2',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='K',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='A1',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='A3',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='K',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='K',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='G',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='A2',func=pin_types.OUTPUT,unit=3),
            Pin(num='4',name='F1',func=pin_types.INPUT,unit=4),
            Pin(num='5',name='F2',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '7', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['9', '8', '7']},{'label': 'uD', 'num': 4, 'pin_nums': ['4', '5']}] }),
        Part(**{ 'name':'CK548DX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CK548DX'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Mini_Pentode_Linear', 'Valve:Valve_Mini_Pentode_Linear'], 'footprint':'Valve:Valve_Mini_Pentode_Linear', 'keywords':'subminiature pentode valve', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nCK548DX\n\nsubminiature pentode valve', 'pins':[
            Pin(num='3',name='F+,G3',func=pin_types.PWRIN),
            Pin(num='1',name='P',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='G2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='F+,G3',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '4', '2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '5']}] }),
        Part(**{ 'name':'ECC83', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ECC83'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Noval_P', 'Valve:Valve_Noval_P'], 'footprint':'Valve:Valve_Noval_P', 'keywords':'triode valve', 'description':'', 'datasheet':'http://www.r-type.org/pdfs/ecc83.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nECC83\n\ntriode valve', 'pins':[
            Pin(num='6',name='A',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='K',func=pin_types.BIDIR,unit=1),
            Pin(num='1',name='A',func=pin_types.OUTPUT,unit=2),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='K',func=pin_types.BIDIR,unit=2),
            Pin(num='4',name='F1',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='F1',func=pin_types.PWRIN,unit=3),
            Pin(num='9',name='F2',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['8', '7', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '1', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '4', '9']}] }),
        Part(**{ 'name':'EF85', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EF85'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Noval_P', 'Valve:Valve_Noval_P'], 'footprint':'Valve:Valve_Noval_P', 'keywords':'pentode valve', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nEF85\n\npentode valve', 'pins':[
            Pin(num='2',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='F1',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='G2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='G3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='F1',func=pin_types.PWRIN,unit=2),
            Pin(num='5',name='F2',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['8', '6', '7', '2', '3', '9']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5']}] }),
        Part(**{ 'name':'EF86', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EF86'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Noval_P', 'Valve:Valve_Noval_P'], 'footprint':'Valve:Valve_Noval_P', 'keywords':'pentode valve', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nEF86\n\npentode valve', 'pins':[
            Pin(num='1',name='G2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='K',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='A',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='G3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='F1',func=pin_types.PWRIN,unit=2),
            Pin(num='5',name='F2',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6', '9', '7', '3', '8']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5']}] }),
        Part(**{ 'name':'JAN6418', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JAN6418'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Mini_Pentode_Linear', 'Valve:Valve_Mini_Pentode_Linear', 'Valve:Valve_Mini_Pentode_Linear'], 'footprint':'Valve:Valve_Mini_Pentode_Linear', 'keywords':'subminiature pentode valve', 'description':'', 'datasheet':'https://frank.pocnet.net/sheets/127/6/6418.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nJAN6418\n\nsubminiature pentode valve', 'pins':[
            Pin(num='3',name='F+,G3',func=pin_types.PWRIN),
            Pin(num='1',name='P',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='G2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='F+,G3',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '2', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '3']}] }),
        Part(**{ 'name':'NOS-6418', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NOS-6418'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Mini_Pentode_Linear', 'Valve:Valve_Mini_Pentode_Linear', 'Valve:Valve_Mini_Pentode_Linear', 'Valve:Valve_Mini_Pentode_Linear'], 'footprint':'Valve:Valve_Mini_Pentode_Linear', 'keywords':'subminiature pentode valve', 'description':'', 'datasheet':'https://frank.pocnet.net/sheets/127/6/6418.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nNOS-6418\n\nsubminiature pentode valve', 'pins':[
            Pin(num='3',name='F+,G3',func=pin_types.PWRIN),
            Pin(num='1',name='P',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='G2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='F+,G3',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '2', '1', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '5']}] }),
        Part(**{ 'name':'PABC80', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PABC80'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Noval_P', 'Valve:Valve_Noval_P', 'Valve:Valve_Noval_P', 'Valve:Valve_Noval_P'], 'footprint':'Valve:Valve_Noval_P', 'keywords':'diode triode valve', 'description':'', 'datasheet':'https://frank.pocnet.net/sheets/082/e/EABC80.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nPABC80\n\ndiode triode valve', 'pins':[
            Pin(num='2',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='K',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='A1',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='A3',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='K',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='K',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='G',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='A2',func=pin_types.OUTPUT,unit=3),
            Pin(num='4',name='F1',func=pin_types.INPUT,unit=4),
            Pin(num='5',name='F2',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '1', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '9', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['5', '4']}] }),
        Part(**{ 'name':'UABC80', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'UABC80'}), 'ref_prefix':'U', 'fplist':['Valve:Valve_Noval_P', 'Valve:Valve_Noval_P', 'Valve:Valve_Noval_P', 'Valve:Valve_Noval_P', 'Valve:Valve_Noval_P'], 'footprint':'Valve:Valve_Noval_P', 'keywords':'diode triode valve', 'description':'', 'datasheet':'https://frank.pocnet.net/sheets/082/e/EABC80.pdf', 'search_text':'/usr/share/kicad/symbols/Valve.kicad_sym\nUABC80\n\ndiode triode valve', 'pins':[
            Pin(num='2',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='K',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='A1',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='A3',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='K',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='K',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='G',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='A2',func=pin_types.OUTPUT,unit=3),
            Pin(num='4',name='F1',func=pin_types.INPUT,unit=4),
            Pin(num='5',name='F2',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '6', '1']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['5', '4']}] })])